@@ -18,8 +18,8 @@ OC.L10N.register(
     "Yesterday" : "Gestern",
     "Today" : "Heute",
     "Tomorrow" : "Morgen",
-    "in %s" : "unter %s",
-    "%s ago" : "%s her",
+    "in %s" : "in %s",
+    "%s ago" : "vor %s",
     "seconds" : "Sekunden",
     "a minute" : "Eine Minute",
     "%d minutes" : "%d Minuten",
@@ -34,7 +34,7 @@ OC.L10N.register(
     "week" : "Woche",
     "weeks" : "Wochen",
     "day" : "Tag",
-    "days" : "Tagen",
+    "days" : "Tage",
     "hour" : "Stunde",
     "hours" : "Stunden",
     "minute" : "Minute",
@@ -63,7 +63,7 @@ OC.L10N.register(
     "Add an item due today in \"%s\"..." : "Einen heute fälligen Eintrag in „%s“ hinzufügen…",
     "Add an item in \"%s\"..." : "Einen Eintrag in „%s“ hinzufügen…",
     "Add a current item in \"%s\"..." : "Einen aktuellen Eintrag in „%s“ hinzufügen…",
-    "Add a subtask to \"%s\"..." : "Füge eine Unteraufgabe zu \"%s\" hinzu...",
+    "Add a subtask to \"%s\"..." : "Füge eine Unteraufgabe zu \"%s\" hinzu…",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n erledigte Aufgabe","%n erledigte Aufgaben"],
     "Hours" : "Stunden",
     "Minutes" : "Minuten",
@@ -98,17 +98,20 @@ OC.L10N.register(
     "Visibility of Smart Collections" : "Sichtbarkeit der intelligenten Sammlungen",
     "Change sort order" : "Sortierreihenfolge ändern",
     "Default" : "Standard",
-    "Due date" : "Ablaufdatum",
+    "Due date" : "Fälligkeitsdatum",
     "Start date" : "Startdatum",
     "Priority" : "Priorität",
     "Alphabetically" : "Alphabetisch",
     "Manually" : "Manuell",
     "Load remaining completed tasks." : "Die restlichen abgeschlossenen Aufgaben laden.",
+    "Task is completed" : "Aufgabe fertiggestellt",
     "All day" : "Ganztägig",
     "(New category)" : "(Neue Kategorie)",
-    "Select categories..." : "Kategorien auswählen...",
+    "Select categories..." : "Kategorien auswählen…",
     "Loading the task..." : "Laden der Aufgabe…",
     "Task not found!" : "Aufgabe nicht gefunden!",
-    "add a subtask to" : "Erstelle eine Unteraufgabe für"
+    "add a subtask to" : "Füge eine Teilaufgabe hinzu",
+    "Toggle subtasks" : "Unteraufgaben umschalten",
+    "Toggle completed subtasks" : "Fertige Unteraufgaben umschalten"
 },
 "nplurals=2; plural=(n != 1);");
