@@ -5,12 +5,12 @@ OC.L10N.register(
     "Due yesterday" : "נועד להתקיים אתמול",
     "Due today" : "נועד להתקיים היום",
     "Due tomorrow" : "נועד להתקיים מחר",
-    "Due on" : "נועד להתקיים ב-",
+    "Due on" : "נועד להתקיים ב־",
     "Started yesterday" : "התחיל אתמול",
     "Starts today" : "מתחיל היום",
     "Starts tomorrow" : "מתחיל מחר",
-    "Started on" : "התחיל ב-",
-    "Starts on" : "מתחיל ב-",
+    "Started on" : "התחיל ב־",
+    "Starts on" : "מתחיל ב־",
     "[Remind me yesterday at ]HH:mm" : "[התזכורת הופעלה אתמול בשעה ]HH:mm",
     "[Remind me today at ]HH:mm" : "[התזכורת מופעלת היום בשעה ]HH:mm",
     "[Remind me tomorrow at ]HH:mm" : "[התזכורת תופעל מחר בשעה ]HH:mm",
@@ -18,8 +18,8 @@ OC.L10N.register(
     "Yesterday" : "אתמול",
     "Today" : "היום",
     "Tomorrow" : "מחר",
-    "in %s" : "ב- %s",
-    "%s ago" : "%s בעבר",
+    "in %s" : "ב־%s",
+    "%s ago" : "לפני %s",
     "seconds" : "שניות",
     "a minute" : "דקה",
     "%d minutes" : "%d דקות",
@@ -39,14 +39,14 @@ OC.L10N.register(
     "hours" : "שעות",
     "minute" : "דקה",
     "minutes" : "דקות",
-    "second" : "שני",
+    "second" : "שניה",
     "before beginning" : "לפני התחלה",
     "after beginning" : "אחרי התחלה",
     "before end" : "לפני סיום",
     "after end" : "אחרי סיום",
     "Comment" : "תגובה",
     "Add a comment" : "הוספת תגובה",
-    "This will delete the Calendar \"%s\" and all of its entries." : "זה ימחוק את היומן \"%s\" ואת כל הרשומות בו.",
+    "This will delete the Calendar \"%s\" and all of its entries." : "פעולה זו תמחק את היומן \"%s\" ואת כל הרשומות בו.",
     "The name \"%s\" is already used." : "השם \"%s\" כבר קיים.",
     "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
     "Hidden" : "מוסתר",
@@ -59,12 +59,12 @@ OC.L10N.register(
     "Thursday" : "יום חמישי",
     "Friday" : "יום שישי",
     "Saturday" : "שבת",
-    "Add an important item in \"%s\"..." : "הוספת פריט חשוב ב- \"%s\"...",
+    "Add an important item in \"%s\"..." : "הוספת פריט חשוב ב־\"%s\"...",
     "Add an item due today in \"%s\"..." : "הוספת פריט שנועד להתקיים היום בשעה \"%s\"...",
-    "Add an item in \"%s\"..." : "הוספת פריט ב- \"%s\"...",
-    "Add a current item in \"%s\"..." : "הוספת פריט נוכחי ב- \"%s\"...",
-    "Add a subtask to \"%s\"..." : "הוספת תת-פעילות ל- \"%s\"...",
-    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות מושלמות"],
+    "Add an item in \"%s\"..." : "הוספת פריט ב־\"%s\"...",
+    "Add a current item in \"%s\"..." : "הוספת פריט נוכחי ב־\"%s\"...",
+    "Add a subtask to \"%s\"..." : "הוספת תת־פעילות ל־\"%s\"...",
+    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו"],
     "Hours" : "שעות",
     "Minutes" : "דקות",
     "Set due date" : "הגדרת תאריך יעד",
@@ -82,7 +82,7 @@ OC.L10N.register(
     "Unnamed" : "ללא שם",
     "Important" : "חשוב",
     "Week" : "שבוע",
-    "All" : "הכל",
+    "All" : "הכול",
     "Current" : "נוכחי",
     "Completed" : "הושלם",
     "Delete" : "מחיקה",
@@ -95,19 +95,23 @@ OC.L10N.register(
     "New List" : "רשימה חדשה",
     "Settings" : "הגדרות",
     "Start of week" : "התחלת שבוע",
-    "Visibility of Smart Collections" : "ניראות של אוספים חכמים",
+    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
     "Change sort order" : "שינוי סדר מיון",
-    "Default" : "ברירת מחדל",
+    "Default" : "בררת מחדל",
     "Due date" : "תאריך יעד",
     "Start date" : "תאריך התחלה",
     "Priority" : "עדיפות",
-    "Alphabetically" : "בצורת אלף-בית",
+    "Alphabetically" : "בסדר האלף-בית",
     "Manually" : "באופן ידני",
-    "Load remaining completed tasks." : "טעינת שארית הפעילויות המושלמות.",
+    "Load remaining completed tasks." : "טעינת שאר הפעילויות שהושלמו.",
+    "Task is completed" : "המשימה הושלמה",
+    "All day" : "כל היום",
     "(New category)" : "(קטגוריה חדשה)",
-    "Select categories..." : "בחירת קטגוריות...",
-    "Loading the task..." : "טעינת הפעילות...",
-    "Task not found!" : "פעילות לא אותרה!",
-    "add a subtask to" : "הוספת תת-פעילות ל-"
+    "Select categories..." : "בחירת קטגוריות…",
+    "Loading the task..." : "המשימה נטענת…",
+    "Task not found!" : "לא אותרה משימה!",
+    "add a subtask to" : "הוספת תת־פעילות ל־",
+    "Toggle subtasks" : "הפעלה/כיבוי של תת־משימות",
+    "Toggle completed subtasks" : "הפעלה/כיבוי של תת־משימות שהושלמו"
 },
 "nplurals=2; plural=(n != 1);");
