@@ -2,7 +2,7 @@ OC.L10N.register(
     "tasks",
     {
     "Tasks" : "Taken",
-    "Due yesterday" : "Vervallen gisteren",
+    "Due yesterday" : "Gisteren vervallen",
     "Due today" : "Vervalt vandaag",
     "Due tomorrow" : "Vervalt morgen",
     "Due on" : "Vervalt op",
@@ -45,7 +45,7 @@ OC.L10N.register(
     "before end" : "voor afsluiting",
     "after end" : "na afsluiting",
     "Comment" : "Reactie",
-    "Add a comment" : "Toevoegen reactie",
+    "Add a comment" : "Reactie toevoegen",
     "This will delete the Calendar \"%s\" and all of its entries." : "Dit verwijdert Kalender \"%s\" en alle afspraken.",
     "The name \"%s\" is already used." : "De naam \"%s\" is al in gebruik.",
     "An empty name is not allowed." : "Een lege naam is niet toegestaan.",
@@ -60,14 +60,14 @@ OC.L10N.register(
     "Friday" : "vrijdag",
     "Saturday" : "zaterdag",
     "Add an important item in \"%s\"..." : "Toevoegen belangrijke taak in \"%s\"...",
-    "Add an item due today in \"%s\"..." : "Toevoegen taak die vandaag vervalt in \"%s\"...",
-    "Add an item in \"%s\"..." : "Toevoegen taak in \"%s\"...",
-    "Add a current item in \"%s\"..." : "Voeg een actuele taak toe aan \"%s\"...",
-    "Add a subtask to \"%s\"..." : "Voeg een subtaak toe aan \"%s\"...",
+    "Add an item due today in \"%s\"..." : "Taak die vandaag vervalt in \"%s\" toevoegen...",
+    "Add an item in \"%s\"..." : "Taak in \"%s\" toevoegen...",
+    "Add a current item in \"%s\"..." : "Actuele taak aan \"%s\" toevoegen...",
+    "Add a subtask to \"%s\"..." : "Subtaak aan \"%s\" toevoegen...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n afgeronde taak","%n afgeronde taken"],
     "Hours" : "Uren",
     "Minutes" : "Minuten",
-    "Set due date" : "Stel vervaldatum in",
+    "Set due date" : "Vervaldatum instellen",
     "%s %% completed" : "%s %% gereed",
     "priority %s: " : "prioriteit %s: ",
     "high" : "hoog",
@@ -77,7 +77,7 @@ OC.L10N.register(
     "Remind me" : "Herinner me",
     "at the end" : "op het eind",
     "at the beginning" : "aan het begin",
-    "Set start date" : "Instellen begindatum",
+    "Set start date" : "Begindatum instellen",
     "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
     "Unnamed" : "Onbenoemd",
     "Important" : "Belangrijk",
@@ -96,19 +96,22 @@ OC.L10N.register(
     "Settings" : "Instellingen",
     "Start of week" : "Begin van de week",
     "Visibility of Smart Collections" : "Zichtbaarheid van Slimme Verzamelingen",
-    "Change sort order" : "Wijzigen volgorde",
+    "Change sort order" : "Volgorde wijzigen",
     "Default" : "Standaard",
     "Due date" : "Vervaldatum",
     "Start date" : "Startdatum",
     "Priority" : "Prioriteit",
     "Alphabetically" : "Alfabetisch",
     "Manually" : "Handmatig",
-    "Load remaining completed tasks." : "Laad overige afgeronde taken",
+    "Load remaining completed tasks." : "Overgebleven afgeronde taken laden.",
+    "Task is completed" : "Taak is gereed",
     "All day" : "Hele dag",
     "(New category)" : "(Nieuwe categorie)",
     "Select categories..." : "Kies categorieën...",
     "Loading the task..." : "Laden van de taak...",
     "Task not found!" : "Taak niet gevonden!",
-    "add a subtask to" : "voeg een subtaak toe aan"
+    "add a subtask to" : "voeg een subtaak toe aan",
+    "Toggle subtasks" : "Wissel subtaken",
+    "Toggle completed subtasks" : "Wissel afgeronde subtaken"
 },
 "nplurals=2; plural=(n != 1);");
